-- Based on https://github.com/nvim-lua/kickstart.nvim (MIT)
-- Inspiration from https://github.com/dam9000/kickstart-modular.nvim (MIT)

-- For reference:
--  https://github.com/LazyVim/LazyVim - Apache-2.0
--  https://github.com/SpaceVim/SpaceVim - GPL-3.0
--  https://github.com/NvChad/NvChad - GPL-3.0
--  https://github.com/AstroNvim/AstroNvim GPL-3.0
--  https://github.com/LunarVim/LunarVim - GPL-3.0

-- Set <space> as the leader key
-- See `:help mapleader`
--  NOTE: Must happen before plugins are loaded (otherwise wrong leader will be used)
vim.g.mapleader = ' '
vim.g.maplocalleader = ' '

-- Arch and platform detection. can be used as conditions for certain plugins.
-- If there is a better/more idiomatic solution, please enlighten me.
-- For a full summary of this table, run ":lua vim.inspect(vim.g.os_uname)"
-- Shows up as undefined but executes and behaves flawlessly as of 2024-08-18
---@diagnostic disable-next-line: undefined-field
vim.g.os_uname = vim.loop.os_uname()
vim.g.sysname = vim.g.os_uname.sysname -- "Linux, FreeBSD, ..."
vim.g.arch = vim.g.os_uname.machine -- "x86_64, ..."

-- Set to true if you have a Nerd Font installed and selected in the terminal
vim.g.have_nerd_font = true

-- [[ Setting options ]]
require 'options'

-- [[ Basic Keymaps ]]
require 'keymaps'

-- [[ Setting autocmd's ]]
require 'autocmd'

-- [[ Install `lazy.nvim` plugin manager ]]
require 'lazy-bootstrap'

-- [[ Configure and install plugins ]]
require 'lazy-plugins'

-- The line beneath this is called `modeline`. See `:help modeline`
-- vim: ts=2 sts=2 sw=2 et
